==> haskell-boolean-0.2.4-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-boolean.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Boolean
version:              0.2.4
visibility:           public
id:                   Boolean-0.2.4-HrseLvCIiC1JtnBXd9m57Y
key:                  Boolean-0.2.4-HrseLvCIiC1JtnBXd9m57Y
license:              BSD-3-Clause
copyright:            (c) 2009-2013 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott
stability:            experimental
synopsis:             Generalized booleans and numbers
description:
    Some classes for generalized boolean operations.
    Starting with 0.1.0, this package uses type families.
    Up to version 0.0.2, it used MPTCs with functional dependencies.
    My thanks to Andy Gill for suggesting & helping with the change.
    Thanks also to Alex Horsman for Data.Boolean.Overload and to
    Jan Bracker for Data.Boolean.Numbers.

    Copyright 2009-2013 Conal Elliott; BSD3 license.

category:             Data
abi:                  4e5647027ade4ec354202320c9c46837
exposed:              True
exposed-modules:
    Data.Boolean Data.Boolean.Numbers Data.Boolean.Overload

import-dirs:          /usr/lib/ghc-9.0.2/site-local/Boolean-0.2.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/Boolean-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-boolean
hs-libraries:         HSBoolean-0.2.4-HrseLvCIiC1JtnBXd9m57Y
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-boolean/html/Boolean.haddock
haddock-html:         /usr/share/doc/haskell-boolean/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-boolean-0.2.4-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-boolean.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Boolean
version:              0.2.4
visibility:           public
id:                   Boolean-0.2.4-2CMdlDEnACACCcpvBHLEzn
key:                  Boolean-0.2.4-2CMdlDEnACACCcpvBHLEzn
license:              BSD-3-Clause
copyright:            (c) 2009-2013 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott
stability:            experimental
synopsis:             Generalized booleans and numbers
description:
    Some classes for generalized boolean operations.
    Starting with 0.1.0, this package uses type families.
    Up to version 0.0.2, it used MPTCs with functional dependencies.
    My thanks to Andy Gill for suggesting & helping with the change.
    Thanks also to Alex Horsman for Data.Boolean.Overload and to
    Jan Bracker for Data.Boolean.Numbers.

    Copyright 2009-2013 Conal Elliott; BSD3 license.

category:             Data
abi:                  9fd8961bad26fc6885f1eac199eaf7d9
exposed:              True
exposed-modules:
    Data.Boolean Data.Boolean.Numbers Data.Boolean.Overload

import-dirs:          /usr/lib/ghc-9.2.8/site-local/Boolean-0.2.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/Boolean-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-boolean
hs-libraries:         HSBoolean-0.2.4-2CMdlDEnACACCcpvBHLEzn
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-boolean/html/Boolean.haddock
haddock-html:         /usr/share/doc/haskell-boolean/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
